@@ -1,5 +1,5 @@
 from ftx.timer import PerpetualTimer
-from ftx.exceptions import FtxValueError, FtxAPIException
+from ftx.exceptions import FtxValueError, FtxAPIException, FtxWebsocketUnableToConnect
 from ftx.authentication import signature, ws_signature
 from ftx.client import Client, AsyncClient
 from ftx.streams import ThreadedWebsocketManager
